@@ -27,18 +27,6 @@ class Activities : public Module
     Q_PROPERTY(QString CurrentActivity READ CurrentActivity WRITE SetCurrentActivity NOTIFY CurrentActivityChanged)
 
 public:
-    /**
-     * Activity state
-     * @note: Do not change the values, needed for bit-operations
-     */
-    enum State {
-        Invalid = 0,
-        Running = 2,
-        Starting = 3,
-        Stopped = 4,
-        Stopping = 5,
-    };
-
     /**
      * Creates new Activities object
      */
@@ -56,23 +44,11 @@ public Q_SLOTS:
      */
     QString CurrentActivity() const;
 
-    /**
-     * @returns the state of the activity
-     * @param activity id of the activity
-     */
-    int ActivityState(const QString &activity) const;
-
     /**
      * @returns the list of all existing activities
      */
     QStringList ListActivities() const;
 
-    /**
-     * @returns the list of activities with the specified state
-     * @param state state
-     */
-    QStringList ListActivities(int state) const;
-
     /**
      * @returns the name of the specified activity
      * @param activity id of the activity
@@ -124,18 +100,6 @@ public Q_SLOTS:
      */
     QString AddActivity(const QString &name);
 
-    /**
-     * Starts the specified activity
-     * @param activity id of the activity to stash
-     */
-    void StartActivity(const QString &activity);
-
-    /**
-     * Stops the specified activity
-     * @param activity id of the activity to stash
-     */
-    void StopActivity(const QString &activity);
-
     /**
      * Removes the specified activity
      * @param activity id of the activity to delete
@@ -177,18 +141,6 @@ Q_SIGNALS:
      */
     void ActivityAdded(const QString &activity);
 
-    /**
-     * This signal is emitted when an activity is started
-     * @param activity id of the activity
-     */
-    void ActivityStarted(const QString &activity);
-
-    /**
-     * This signal is emitted when an activity is stashed
-     * @param activity id of the activity
-     */
-    void ActivityStopped(const QString &activity);
-
     /**
      * This signal is emitted when an activity is deleted
      * @param activity id of the activity
@@ -222,11 +174,6 @@ Q_SIGNALS:
      */
     void ActivityChanged(const QString &activity);
 
-    /**
-     * Emitted when the state of activity is changed
-     */
-    void ActivityStateChanged(const QString &activity, int state);
-
 private:
     D_PTR;
 };
